function [ SOLUTION, finalNodes, remainingNodes, param ] = analyzeBivOfBm_BB_aux( Sxx, Sxy, Syy, Jvalues,interv, param, prec, remainingNodes)



%Assignments
diffval                     = +Inf;
Jvalues                     = Jvalues';
S.xx                        = Sxx';
S.xy                        = Sxy';
S.yy                        = Syy';
param.flag                  = false;
flag                        = true;
savedNodes_ind              = 1; %Saved nodes (whose interval has reached the minimum size)




%% INITIALIZATION


if nargin <= 7          %%%%%%%% First call %%%%%%%%
    
    % Load tab values of etahOfBm / etahOfGn
    if strcmp(param.dataType,'ofbm');
        filename = which('tab_etahOfBm.mat');
        load(filename,'etah');
        param.expcst    = 1+2*param.mu_bb;
    else
        filename = which('tab_etahOfGn.mat');
        load(filename,'etah');
        param.expcst    = -1+2*param.mu_bb;
    end
    param.etah_tab  = etah;
    
    
    % First node(s): Approximation by a union of convex sets
    [ remainingNodes, GLOBAL_U, GLOBAL_L, ind_nextNode ] = bb_initialization_7p( Jvalues, S, interv, param.divisionStep, prec, param.crossTerm, param.etah_tab, param.expcst, param.dataType);
    
    
    % Assigments
    if param.dispAlg
        param.fig = figure;
    end
    ii = 1;
    
else                    %%%%%%%% Next calls %%%%%%%%
    
    GLOBAL_U        = param.global_u;
    GLOBAL_L        = param.global_l;
    ind_nextNode    = param.nextnode;
    gblu            = param.listbnd_u;
    gbll            = param.listbnd_l;
    mdiffval        = param.listdiff;
    nbnodes         = param.listnbnode;
    ii              = param.ite;
    savedNodes_ind  = param.savedNodesInd;
    if savedNodes_ind > 1
        savedNodes  = param.saved;
    end
    
    
end


%Permit to stop the algorithm on demand
if param.dispAlg
    h = param.fig;
    set(h,'currentcharacter','a')
    disp('Press any key to stop the algorithm...')
end




%% ITERATIONS



while flag

    
    % (1) -  Select next node to proceed
    node            = remainingNodes(ind_nextNode);
    remainingNodes(ind_nextNode) = [];
   
    
    
    % (2) - Divide the longest edge in half and create 2 nodes
    [nodeA,nodeB,flagempty] = bb_divideNode_7p(node,prec);
    
    
    if ~flagempty
       
        % (3) - Evaluates both lower and upper bound for each node & Update global upper bound
        nodeA.L     = ia2LowerBoundGeneral_7p( Jvalues, S, nodeA.interv, param.crossTerm, param.etah_tab, param.expcst, param.dataType );
        nodeB.L     = ia2LowerBoundGeneral_7p( Jvalues, S, nodeB.interv, param.crossTerm, param.etah_tab, param.expcst, param.dataType );
        nodeA.U     = eval2UpperBoundGeneral_7p( Jvalues, S, nodeA.interv, param.crossTerm, param.etah_tab, param.expcst, param.dataType );
        nodeB.U     = eval2UpperBoundGeneral_7p( Jvalues, S, nodeB.interv, param.crossTerm, param.etah_tab, param.expcst, param.dataType );
        GLOBAL_U    = min([GLOBAL_U, nodeA.U, nodeB.U]);
        
        if nodeA.L > nodeA.U
            disp('Error in node A : Lower bound > Upper bound')
        end
        if nodeB.L > nodeB.U
            disp('Error in node B : Lower bound > Upper bound')
        end
        
        
        
        % (4) - Add nodes which may contain the global minimizer to the list
        if nodeA.L <= GLOBAL_U
            if bb_intervalLargeEnough( nodeA, prec )
                remainingNodes(end+1)       = nodeA;
            else
                savedNodes(savedNodes_ind)  = nodeA;
                savedNodes_ind              = savedNodes_ind + 1;
            end
        end
        if nodeB.L <= GLOBAL_U
            if bb_intervalLargeEnough( nodeB, prec )
                remainingNodes(end+1)       = nodeB;
            else
                savedNodes(savedNodes_ind)  = nodeB;
                savedNodes_ind              = savedNodes_ind + 1;
            end
        end
        
    end

           
    % (5) - Prune the tree & select next node
    [remainingNodes,ind_nextNode] = bb_pruning( remainingNodes, GLOBAL_U );
    if ~isempty(ind_nextNode)
        GLOBAL_L = remainingNodes(ind_nextNode).L;
    end

    
    
    % (6) - Bounds difference
    diffval = (GLOBAL_U - GLOBAL_L)/GLOBAL_U;

    
    
    % (7) - Display
    nbnodes(ii)     = length(remainingNodes);
    mdiffval(ii)    = diffval;
    gblu(ii)        = GLOBAL_U;
    gbll(ii)        = GLOBAL_L;
    ii              = ii+1;
    
    if param.dispSol ~= 0 && mod(ii,param.dispSol) == 0
        [~,ind]     = min([remainingNodes.U]);
        currentSol  = remainingNodes(ind);
        bb_dispSol(currentSol)
    end

    if param.dispAlg
        figure(h)
        subplot(311);
        loglog(gblu,'r','linewidth',2); hold on;
        loglog(gbll,'b','linewidth',2);
        title('(lowest) upper bound \& (lowest) lower bound','Interpreter','latex');
        l=legend('Upper','Lower');%,'Location','Best');
        set(l,'Interpreter','latex');
        set(gca,'fontsize',20);
        grid on;
        subplot(312);
        loglog(mdiffval,'k','linewidth',2);
        title('Relative bounds difference','Interpreter','latex')
        set(gca,'fontsize',20);
        grid on;
        subplot(313);
        loglog(nbnodes,'k','linewidth',2);
        title('Number of partitions','Interpreter','latex')
        set(gca,'fontsize',20);
        grid on;
        drawnow
        
        flag = diffval >= param.EPS && ~isempty(remainingNodes) && get(gcf,'currentcharacter')=='a' && ii < param.itelim;
        
    else
        
        flag = diffval >= param.EPS && ~isempty(remainingNodes) && ii < param.itelim;
        
    end
    
    
       
end


%% TERMINATION



% - Ending
if diffval >= param.EPS && ~isempty(remainingNodes) && ii < param.itelim;
    disp('Algorithm stopped by the user.');
else
    disp('Accuracy limit reached. End of the algorithm.');
    param.flag = true;
end



% - Solution = partion with lowest upper bound
finalNodes      = remainingNodes;
if savedNodes_ind > 1
    [savedNodes] = bb_pruning(savedNodes, GLOBAL_U );
    
    ind = length(finalNodes);
    for jj = 1:length(savedNodes)
        finalNodes(ind+jj) = savedNodes(jj);
    end
end
ub_list = [finalNodes.U];
[~,ind] = min(ub_list);
SOLUTION = finalNodes(ind);



% - Savings
param.global_u      = GLOBAL_U;
param.global_l      = GLOBAL_L;
param.nextnode      = ind_nextNode;
param.listbnd_u     = gblu;
param.listbnd_l     = gbll;
param.listdiff      = mdiffval;
param.listnbnode    = nbnodes;
param.ite           = ii;
param.savedNodesInd = savedNodes_ind;
if savedNodes_ind > 1
param.saved         = savedNodes;
end
if param.dispAlg
   param.fig        = h;
end

end

