function [ nodeA, nodeB, flagempty ] = bb_divideNode_7p( node,prec )
% bb_divideNode: divides the given node along its longest edge into two
% nodes 'nodeA' and 'nodeB'.

flagempty       = false;

nodeA           = node;
nodeB           = node;

int_h1          = node.interv.h1;
int_h2          = node.interv.h2;
int_beta        = node.interv.beta;
int_gamma       = node.interv.gamma;
int_sigma1      = node.interv.sigma1;
int_sigma2      = node.interv.sigma2;
int_rho         = node.interv.rho;

length_h1       = ia_length(int_h1)/prec.h1;
length_h2       = ia_length(int_h2)/prec.h2;
length_beta     = ia_length(int_beta)/prec.beta;
length_gamma    = ia_length(int_gamma)/prec.gamma;
length_sigma1   = ia_length(int_sigma1)/prec.sigma1;
length_sigma2   = ia_length(int_sigma2)/prec.sigma2;
length_rho      = ia_length(int_rho)/prec.rho;


max_length      = max([length_h1, length_h2, length_beta, length_gamma, length_sigma1, length_sigma2, length_rho]);



if length_h1 == max_length

    [ int_h1, int_h2 ]  = bb_constrh1leqh2( int_h1, int_h2 );
    
    mid                 = ia_mid(int_h1);

    
    if isempty(int_h1) && isempty(int_h2)
        nodeA.interv.h1     = [];
        nodeB.interv.h1     = [];
        nodeA.interv.h2     = [];
        nodeB.interv.h2     = [];
        flagempty           = true;
    else
    int_inf             = [int_h1(1)    mid];
    int_sup             = [mid          int_h1(2)];
    
    nodeA.interv.h2     = int_h2;
    nodeB.interv.h2     = int_h2;
    nodeA.interv.h1     = int_inf;
    nodeB.interv.h1     = int_sup;
    end

    
elseif length_h2 == max_length

    [ int_h1, int_h2 ]  = bb_constrh1leqh2( int_h1, int_h2 );
    
    mid                 = ia_mid(int_h2);
    
    if isempty(int_h1) && isempty(int_h2)
        nodeA.interv.h1     = [];
        nodeB.interv.h1     = [];
        nodeA.interv.h2     = [];
        nodeB.interv.h2     = [];
        flagempty           = true;
    else
        int_inf             = [int_h2(1)    mid];
        int_sup             = [mid          int_h2(2)];
        
        nodeA.interv.h1     = int_h1;
        nodeB.interv.h1     = int_h1;
        nodeA.interv.h2     = int_inf;
        nodeB.interv.h2     = int_sup; 
    end
    
elseif length_beta == max_length
    
    mid                 = ia_mid(int_beta);
    int_inf             = [int_beta(1) mid];
    int_sup             = [mid          int_beta(2)];
    
    nodeA.interv.beta   = int_inf;
    nodeB.interv.beta   = int_sup;

    
elseif length_gamma == max_length
    
    mid                 = ia_mid(int_gamma);
    int_inf             = [int_gamma(1) mid];
    int_sup             = [mid          int_gamma(2)];
    
    nodeA.interv.gamma  = int_inf;
    nodeB.interv.gamma  = int_sup;

    
elseif length_sigma1 == max_length
    
    mid                 = ia_mid(int_sigma1);
    int_inf             = [int_sigma1(1)    mid];
    int_sup             = [mid              int_sigma1(2)];
    
    nodeA.interv.sigma1 = int_inf;
    nodeB.interv.sigma1 = int_sup;

    
elseif length_sigma2 == max_length
    
    mid                 = ia_mid(int_sigma2);
    int_inf             = [int_sigma2(1)    mid];
    int_sup             = [mid              int_sigma2(2)];
    
    nodeA.interv.sigma2 = int_inf;
    nodeB.interv.sigma2 = int_sup;

    
elseif length_rho == max_length
    
    mid                 = ia_mid(int_rho);
    int_inf             = [int_rho(1)    mid];
    int_sup             = [mid           int_rho(2)];
    
    nodeA.interv.rho    = int_inf;
    nodeB.interv.rho    = int_sup;
    
end


end

