function [ lb ] = ia2LowerBoundGeneral_7p( Jvalues, S, interv, crossterm, etah, expcst, dataType)
%IA2LOWERBOUND gives a lower bound to the "functional considered" by means of interval arithmetic




h1      = interv.h1;
h2      = interv.h2;
s1      = interv.sigma1;
s2      = interv.sigma2;
rho     = interv.rho;
b       = interv.beta;
g       = interv.gamma;

s12     = ia_square(s1);
s22     = ia_square(s2);
b2      = ia_square(b);
g2      = ia_square(g);
bg      = ia_multiply(b,g);

invg2   = ia_inverse(1+g2);
invb2   = ia_inverse(1+b2);
invbg   = ia_sqrt( ia_multiply(invg2, invb2) );


if strcmp(dataType,'ofbm')
    eta1    = ia_etahOfBm(h1,etah);
    eta2    = ia_etahOfBm(h2,etah);
    eta12   = ia_etahOfBm((h1+h2)/2,etah);
    R       = ones(length(Jvalues),1);
else
    eta1    = ia_etahOfGn(h1,Jvalues,etah);
    eta2    = ia_etahOfGn(h2,Jvalues,etah);
    eta12   = ia_etahOfGn((h1+h2)/2,Jvalues,etah);
    R       = 1;
end


l1      = ia_multiply( s12, ia_multiply(eta1, invg2) );
l12     = ia_multiply( s1, ia_multiply( s2, ia_multiply(rho, ia_multiply( eta12, invbg) ) ) );
l2      = ia_multiply( s22, ia_multiply(eta2, invb2) );


axx1    = R*l1;
axx12   = R*ia_multiply(l12, 2*b);
axx2    = R*ia_multiply(l2, b2);
 

ayy1    = R*ia_multiply(l1, g2);
ayy12   = R*ia_neg(ia_multiply(l12, 2*g));
ayy2    = R*l2;


e1      = 2.^(Jvalues*(2*h1+expcst));
e12     = 2.^(Jvalues*(h1+h2+expcst));
e2      = 2.^(Jvalues*(2*h2+expcst));


Spxx    = axx1.*e1 + axx12.*e12 + axx2.*e2;
Spyy    = ayy1.*e1 + ayy12.*e12 + ayy2.*e2;


Spxx    = ia_zeroCheck(Spxx);
Spyy    = ia_zeroCheck(Spyy);


mlogxx  = ia_neg(log2(Spxx));
mlogyy  = ia_neg(log2(Spyy));


tmpxx   = [log2(S.xx) log2(S.xx)];
tmpyy   = [log2(S.yy) log2(S.yy)];


diffxx  = sum( ia_square(tmpxx + mlogxx) );
diffyy  = sum( ia_square(tmpyy + mlogyy) );


if crossterm
    axy1    = R*ia_neg(ia_multiply(l1,g));
    axy12   = R*ia_multiply(l12,1+ia_neg(bg));
    axy2    = R*ia_multiply(l2,b);
    
    Spxy    = ia_abs(axy1.*e1 + axy12.*e12 + axy2.*e2);
    Spxy    = ia_zeroCheck(Spxy);
    mlogxy  = ia_neg(log2(Spxy));
    tmpxy   = [log2(abs(S.xy)) log2(abs(S.xy))];
    
    diffxy  = sum( ia_square(tmpxy + mlogxy) );
    
    crit    = diffxx + diffyy + diffxy;
else
    crit    = diffxx + diffyy;
end

lb      = crit(1);


if ~isreal(lb)
    disp('lb not real');
end

if isnan(lb)
    disp('lb not a number');
end

  
end

