function int = etahOfBm(h,Nwt,method)
%coeffOndelette: returns the result of following integral:
% (-1/2) * integral_R { |u|^(2h) du } * integral_R { psi(v)*psi(u-v) dv },
% where 'h' stands for an Hurst exponent and 'psi' corresponds to the
% Daubechies 'Nwt' tap wavelet.
%
% Input : - 'h' Hurst exponent
%         - 'Nwt' (=2 by default)
%         - 'method' (=1 by default) permits to choose the ingretation
%            technique



if nargin == 1
    Nwt = 2;
    disp('coeffOndelette, default: Nwt=2')
end

if nargin <= 2
    method      = 1;
end

nbvoies     = 15;



switch method
    case 1    % Patrice's trick
        
        [u1, Psi1]  = genDaubechies2(nbvoies,Nwt);
        du          = diff(u1);
        [val ind]   = max(abs(Psi1));
        u1          = u1 - u1(ind);
        Psi1        = Psi1./val;
        
        
        
        
        int         = -sum(Psi1.*abs(u1).^(2*h).*du(1))/2;
               
        
    case 2     % Naive Integration
        
        [u2, psi]   = genDaubechies(nbvoies,Nwt);
        du          = diff(u2);
        psir        = fliplr(psi);
        Psi2        = conv(psi,psir,'same').*du(1);
        
        [val ind]   = max(abs(Psi2));
        u2          = u2 - u2(ind);
        
        
        int         = (-1/2)*sum( abs(u2).^(2*h).*Psi2.*du(1));
        
        
        
    case 3      % Ttrap?zoidale Integration
        
        [u2, psi]   = genDaubechies(nbvoies,Nwt);
        du          = diff(u2);
        psir        = fliplr(psi);
        Psi2        = conv(psi,psir,'same').*du(1);
        
        [val ind]   = max(abs(Psi2));
        u2          = u2 - u2(ind);
        
        
        int         = (-1/2)*trapz(u2, abs(u2).^(2*h).*Psi2);
end




